Latent time joint mixed effect model with univariate normal distributions on random effects fit with stan

ltjmm_stan(
  formula,
  lt = TRUE,
  random_effects = "univariate",
  data,
  subset,
  na.action,
  ...
)

Arguments

formula

a Formula with rhs denoted the outcome in the stacked dataset, and rhs with 4 parts, e.g.: Y ~ variable for observation time | fixed effects | subject id | outcome id

lt

logical, indicating whether or not latent time effect should be included.

random_effects

character specifying distribution for random intercepts and slopes. Option 'univariate' specifies that random intercepts and slopes for each outcome follow univariate independent normal distributions. Option 'multivariate' specifies that random intercepts and slopes follow a single multivariate normal distribution. Option 'multivariate_no_constraint' with lt=TRUE relaxes the sum-to-zero constraint described in Li et al. 2017. Option 'none' drops random intercepts and slopes from the model.

data

data.frame containing the variables in the model.

subset

an optional vector specifying a subset of observations to be used in the fitting process.

na.action

a function which indicates what should happen when the data contain NAs.

...

Arguments passed to `cmdstanr::sample` (e.g. iter_warmup, iter_sampling, chains, parallel_chains).

Value

A CmdStanMCMC object.

See also