ltjmm.RdLTJMM data setup for fitting with rstan
ltjmm(formula, data, subset, na.action)a Formula with rhs denoted the outcome in the
stacked dataset, and rhs with 4 parts, e.g.: Y ~ variable for observation time | fixed
effects | subject id | outcome id
data.frame containing the variables in the model.
an optional vector specifying a subset of observations to be used in the fitting process.
a function which indicates what should happen when the data contain NAs.